@@ -3,7 +3,7 @@
  *                Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -51,6 +51,7 @@
 #include <iostream>
 #include <limits>
 #include <sstream>
+#include <string>
 
 #include "arkode/arkode_arkstep.h"     // access to ARKStep
 #include "mpi.h"                       // MPI header file
@@ -59,11 +60,10 @@
 #include "sunlinsol/sunlinsol_spgmr.h" // access to SPGMR SUNLinearSolver
 
 // Macros for problem constants
-#define PI    SUN_RCONST(3.141592653589793238462643383279502884197169)
-#define ZERO  SUN_RCONST(0.0)
-#define ONE   SUN_RCONST(1.0)
-#define TWO   SUN_RCONST(2.0)
-#define EIGHT SUN_RCONST(8.0)
+#define PI   SUN_RCONST(3.141592653589793238462643383279502884197169)
+#define ZERO SUN_RCONST(0.0)
+#define ONE  SUN_RCONST(1.0)
+#define TWO  SUN_RCONST(2.0)
 
 // Macro to access (x,y) location in 1D NVector array
 #define IDX(x, y, n) ((n) * (y) + (x))
@@ -164,7 +164,7 @@ struct UserData
   sunrealtype atol;   // absolute tolerance
   sunrealtype hfixed; // fixed step size
   int order;          // ARKode method order
-  int controller;     // step size adaptivity method
+  string controller;  // step size adaptivity method
   int maxsteps;       // max number of steps between outputs
   bool linear;        // enable/disable linearly implicit option
   bool diagnostics;   // output diagnostics
@@ -271,12 +271,11 @@ static int check_flag(void* flagvalue, const string funcname, int opt);
 
 int main(int argc, char* argv[])
 {
-  int flag;                    // reusable error-checking flag
-  UserData* udata      = NULL; // user data structure
-  N_Vector u           = NULL; // vector for storing solution
-  SUNLinearSolver LS   = NULL; // linear solver memory structure
-  void* arkode_mem     = NULL; // ARKODE memory structure
-  SUNAdaptController C = NULL; // timestep adaptivity controller
+  int flag;                  // reusable error-checking flag
+  UserData* udata    = NULL; // user data structure
+  N_Vector u         = NULL; // vector for storing solution
+  SUNLinearSolver LS = NULL; // linear solver memory structure
+  void* arkode_mem   = NULL; // ARKODE memory structure
 
   // Timing variables
   double t1 = 0.0;
@@ -450,17 +449,8 @@ int main(int argc, char* argv[])
   }
   else
   {
-    switch (udata->controller)
-    {
-    case (ARK_ADAPT_PID): C = SUNAdaptController_PID(ctx); break;
-    case (ARK_ADAPT_PI): C = SUNAdaptController_PI(ctx); break;
-    case (ARK_ADAPT_I): C = SUNAdaptController_I(ctx); break;
-    case (ARK_ADAPT_EXP_GUS): C = SUNAdaptController_ExpGus(ctx); break;
-    case (ARK_ADAPT_IMP_GUS): C = SUNAdaptController_ImpGus(ctx); break;
-    case (ARK_ADAPT_IMEX_GUS): C = SUNAdaptController_ImExGus(ctx); break;
-    }
-    flag = ARKodeSetAdaptController(arkode_mem, C);
-    if (check_flag(&flag, "ARKodeSetAdaptController", 1)) { return 1; }
+    flag = ARKodeSetAdaptControllerByName(arkode_mem, udata->controller.c_str());
+    if (check_flag(&flag, "ARKodeSetAdaptControllerByName", 1)) { return 1; }
   }
 
   // Specify linearly implicit non-time-dependent RHS
@@ -565,9 +555,8 @@ int main(int argc, char* argv[])
   N_VDestroy(u);           // Free vectors
   FreeUserData(udata);     // Free user data
   delete udata;
-  (void)SUNAdaptController_Destroy(C); // Free timestep adaptivity controller
-  SUNContext_Free(&ctx);               // Free context
-  flag = MPI_Finalize();               // Finalize MPI
+  SUNContext_Free(&ctx); // Free context
+  flag = MPI_Finalize(); // Finalize MPI
   return 0;
 }
 
@@ -1330,7 +1319,7 @@ static int InitUserData(UserData* udata)
   udata->atol        = SUN_RCONST(1.e-10); // absolute tolerance
   udata->hfixed      = ZERO;               // using adaptive step sizes
   udata->order       = 3;                  // method order
-  udata->controller  = 0;                  // PID controller
+  udata->controller  = "I";                // controller
   udata->maxsteps    = 0;                  // use default
   udata->linear      = true;               // linearly implicit problem
   udata->diagnostics = false;              // output diagnostics
@@ -1440,10 +1429,7 @@ static int ReadInputs(int* argc, char*** argv, UserData* udata, bool outproc)
     else if (arg == "--atol") { udata->atol = stod((*argv)[arg_idx++]); }
     else if (arg == "--fixedstep") { udata->hfixed = stod((*argv)[arg_idx++]); }
     else if (arg == "--order") { udata->order = stoi((*argv)[arg_idx++]); }
-    else if (arg == "--controller")
-    {
-      udata->controller = stoi((*argv)[arg_idx++]);
-    }
+    else if (arg == "--controller") { udata->controller = (*argv)[arg_idx++]; }
     else if (arg == "--nonlinear") { udata->linear = false; }
     else if (arg == "--diagnostics") { udata->diagnostics = true; }
     // Linear solver settings
