@@ -4,7 +4,7 @@
  *                Radu Serban and Aaron Collier @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -348,7 +348,7 @@ int CVBandPrecGetNumRhsEvals(void* cvode_mem, long int* nfevalsBP)
 
   gamma   is the scalar appearing in the Newton matrix.
 
-  bp_data is a pointer to preconditoner data (set by cvBandPrecInit)
+  bp_data is a pointer to preconditioner data (set by cvBandPrecInit)
 
   The value to be returned by the cvBandPrecSetup function is
     0  if successful, or
@@ -431,16 +431,19 @@ static int cvBandPrecSetup(sunrealtype t, N_Vector y, N_Vector fy,
 
   r       is the right-hand side vector of the linear system.
 
-  bp_data is a pointer to preconditoner data (set by CVBandPrecInit)
+  bp_data is a pointer to preconditioner data (set by CVBandPrecInit)
 
   z       is the output vector computed by cvBandPrecSolve.
 
   The value returned by the cvBandPrecSolve function is always 0,
   indicating success.
   -----------------------------------------------------------------*/
-static int cvBandPrecSolve(sunrealtype t, N_Vector y, N_Vector fy, N_Vector r,
-                           N_Vector z, sunrealtype gamma, sunrealtype delta,
-                           int lr, void* bp_data)
+static int cvBandPrecSolve(SUNDIALS_MAYBE_UNUSED sunrealtype t,
+                           SUNDIALS_MAYBE_UNUSED N_Vector y,
+                           SUNDIALS_MAYBE_UNUSED N_Vector fy, N_Vector r,
+                           N_Vector z, SUNDIALS_MAYBE_UNUSED sunrealtype gamma,
+                           SUNDIALS_MAYBE_UNUSED sunrealtype delta,
+                           SUNDIALS_MAYBE_UNUSED int lr, void* bp_data)
 {
   CVBandPrecData pdata;
   int retval;
