@@ -2,7 +2,7 @@
  * Programmer(s): David J. Gardner @ LLNL
  * -----------------------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -233,7 +233,8 @@ int idaNlsInit(IDAMem IDA_mem)
   return (IDA_SUCCESS);
 }
 
-static int idaNlsLSetup(sunbooleantype jbad, sunbooleantype* jcur, void* ida_mem)
+static int idaNlsLSetup(SUNDIALS_MAYBE_UNUSED sunbooleantype jbad,
+                        sunbooleantype* jcur, void* ida_mem)
 {
   IDAMem IDA_mem;
   int retval;
@@ -318,7 +319,8 @@ static int idaNlsResidual(N_Vector ycor, N_Vector res, void* ida_mem)
   return (IDA_SUCCESS);
 }
 
-static int idaNlsConvTest(SUNNonlinearSolver NLS, N_Vector ycor, N_Vector del,
+static int idaNlsConvTest(SUNNonlinearSolver NLS,
+                          SUNDIALS_MAYBE_UNUSED N_Vector ycor, N_Vector del,
                           sunrealtype tol, N_Vector ewt, void* ida_mem)
 {
   IDAMem IDA_mem;
