@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -17,11 +17,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <sunadaptcontroller/sunadaptcontroller_imexgus.h>
-#include <sundials/sundials_core.h>
 
-#include "sundials/priv/sundials_errors_impl.h"
-#include "sundials/sundials_errors.h"
+#include <sunadaptcontroller/sunadaptcontroller_imexgus.h>
+#include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_core.h>
+#include <sundials/sundials_errors.h>
+
+#include "sundials_macros.h"
 
 /* ---------------
  * Macro accessors
@@ -45,8 +47,7 @@
 #define DEFAULT_K2E  SUN_RCONST(0.268)
 #define DEFAULT_K1I  SUN_RCONST(0.95)
 #define DEFAULT_K2I  SUN_RCONST(0.95)
-#define DEFAULT_BIAS SUN_RCONST(1.5)
-#define TINY         SUN_RCONST(1.0e-10)
+#define DEFAULT_BIAS SUN_RCONST(1.0)
 
 /* -----------------------------------------------------------------
  * exported functions
@@ -113,7 +114,8 @@ SUNErrCode SUNAdaptController_SetParams_ImExGus(SUNAdaptController C,
  * implementation of controller operations
  * ----------------------------------------------------------------- */
 
-SUNAdaptController_Type SUNAdaptController_GetType_ImExGus(SUNAdaptController C)
+SUNAdaptController_Type SUNAdaptController_GetType_ImExGus(
+  SUNDIALS_MAYBE_UNUSED SUNAdaptController C)
 {
   return SUN_ADAPTCONTROLLER_H;
 }
@@ -125,28 +127,27 @@ SUNErrCode SUNAdaptController_EstimateStep_ImExGus(SUNAdaptController C,
 {
   SUNFunctionBegin(C->sunctx);
 
-  SUNAssert(hnew, SUN_ERR_ARG_CORRUPT);
-
   /* order parameter to use */
   const int ord = p + 1;
 
-  /* set usable time-step adaptivity parameters -- first step */
-  const sunrealtype k = -SUN_RCONST(1.0) / ord;
-  const sunrealtype e = SUNMAX(SACIMEXGUS_BIAS(C) * dsm, TINY);
-
-  /* set usable time-step adaptivity parameters -- subsequent steps */
-  const sunrealtype k1e  = -SACIMEXGUS_K1E(C) / ord;
-  const sunrealtype k2e  = -SACIMEXGUS_K2E(C) / ord;
-  const sunrealtype k1i  = -SACIMEXGUS_K1I(C) / ord;
-  const sunrealtype k2i  = -SACIMEXGUS_K2I(C) / ord;
-  const sunrealtype e1   = SUNMAX(SACIMEXGUS_BIAS(C) * dsm, TINY);
-  const sunrealtype e2   = e1 / SUNMAX(SACIMEXGUS_EP(C), TINY);
-  const sunrealtype hrat = h / SACIMEXGUS_HP(C);
-
   /* compute estimated time step size, modifying the first step formula */
-  if (SACIMEXGUS_FIRSTSTEP(C)) { *hnew = h * SUNRpowerR(e, k); }
+  if (SACIMEXGUS_FIRSTSTEP(C))
+  {
+    /* set usable time-step adaptivity parameters -- first step */
+    const sunrealtype k = -SUN_RCONST(1.0) / ord;
+    const sunrealtype e = SACIMEXGUS_BIAS(C) * dsm;
+    *hnew               = h * SUNRpowerR(e, k);
+  }
   else
   {
+    /* set usable time-step adaptivity parameters -- subsequent steps */
+    const sunrealtype k1e  = -SACIMEXGUS_K1E(C) / ord;
+    const sunrealtype k2e  = -SACIMEXGUS_K2E(C) / ord;
+    const sunrealtype k1i  = -SACIMEXGUS_K1I(C) / ord;
+    const sunrealtype k2i  = -SACIMEXGUS_K2I(C) / ord;
+    const sunrealtype e1   = SACIMEXGUS_BIAS(C) * dsm;
+    const sunrealtype e2   = e1 / SACIMEXGUS_EP(C);
+    const sunrealtype hrat = h / SACIMEXGUS_HP(C);
     *hnew = h * SUNMIN(hrat * SUNRpowerR(e1, k1i) * SUNRpowerR(e2, k2i),
                        SUNRpowerR(e1, k1e) * SUNRpowerR(e2, k2e));
   }
@@ -165,12 +166,9 @@ SUNErrCode SUNAdaptController_Reset_ImExGus(SUNAdaptController C)
 SUNErrCode SUNAdaptController_SetDefaults_ImExGus(SUNAdaptController C)
 {
   SUNFunctionBegin(C->sunctx);
-  SACIMEXGUS_K1E(C)  = DEFAULT_K1E;
-  SACIMEXGUS_K2E(C)  = DEFAULT_K2E;
-  SACIMEXGUS_K1I(C)  = DEFAULT_K1I;
-  SACIMEXGUS_K2I(C)  = DEFAULT_K2I;
   SACIMEXGUS_BIAS(C) = DEFAULT_BIAS;
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_ImExGus(C, DEFAULT_K1E, DEFAULT_K2E,
+                                              DEFAULT_K1I, DEFAULT_K2I);
 }
 
 SUNErrCode SUNAdaptController_Write_ImExGus(SUNAdaptController C, FILE* fptr)
@@ -178,23 +176,13 @@ SUNErrCode SUNAdaptController_Write_ImExGus(SUNAdaptController C, FILE* fptr)
   SUNFunctionBegin(C->sunctx);
   SUNAssert(fptr, SUN_ERR_ARG_CORRUPT);
   fprintf(fptr, "ImEx Gustafsson SUNAdaptController module:\n");
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-  fprintf(fptr, "  k1e = %32Lg\n", SACIMEXGUS_K1E(C));
-  fprintf(fptr, "  k2e = %32Lg\n", SACIMEXGUS_K2E(C));
-  fprintf(fptr, "  k1i = %32Lg\n", SACIMEXGUS_K1I(C));
-  fprintf(fptr, "  k2i = %32Lg\n", SACIMEXGUS_K2I(C));
-  fprintf(fptr, "  bias factor = %22Lg\n", SACIMEXGUS_BIAS(C));
-  fprintf(fptr, "  previous error = %22Lg\n", SACIMEXGUS_EP(C));
-  fprintf(fptr, "  previous step = %22Lg\n", SACIMEXGUS_HP(C));
-#else
-  fprintf(fptr, "  k1e = %16g\n", SACIMEXGUS_K1E(C));
-  fprintf(fptr, "  k2e = %16g\n", SACIMEXGUS_K2E(C));
-  fprintf(fptr, "  k1i = %16g\n", SACIMEXGUS_K1I(C));
-  fprintf(fptr, "  k2i = %16g\n", SACIMEXGUS_K2I(C));
-  fprintf(fptr, "  bias factor = %16g\n", SACIMEXGUS_BIAS(C));
-  fprintf(fptr, "  previous error = %16g\n", SACIMEXGUS_EP(C));
-  fprintf(fptr, "  previous step = %16g\n", SACIMEXGUS_HP(C));
-#endif
+  fprintf(fptr, "  k1e = " SUN_FORMAT_G "\n", SACIMEXGUS_K1E(C));
+  fprintf(fptr, "  k2e = " SUN_FORMAT_G "\n", SACIMEXGUS_K2E(C));
+  fprintf(fptr, "  k1i = " SUN_FORMAT_G "\n", SACIMEXGUS_K1I(C));
+  fprintf(fptr, "  k2i = " SUN_FORMAT_G "\n", SACIMEXGUS_K2I(C));
+  fprintf(fptr, "  bias factor = " SUN_FORMAT_G "\n", SACIMEXGUS_BIAS(C));
+  fprintf(fptr, "  previous error = " SUN_FORMAT_G "\n", SACIMEXGUS_EP(C));
+  fprintf(fptr, "  previous step = " SUN_FORMAT_G "\n", SACIMEXGUS_HP(C));
   return SUN_SUCCESS;
 }
 
