@@ -2,7 +2,7 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2024, Lawrence Livermore National Security
+ * Copyright (c) 2002-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -17,28 +17,31 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <sunadaptcontroller/sunadaptcontroller_soderlind.h>
-#include <sundials/sundials_core.h>
 
-#include "sundials/priv/sundials_errors_impl.h"
-#include "sundials/sundials_errors.h"
+#include <sunadaptcontroller/sunadaptcontroller_soderlind.h>
+#include <sundials/priv/sundials_errors_impl.h>
+#include <sundials/sundials_core.h>
+#include <sundials/sundials_errors.h>
+
+#include "sundials_macros.h"
 
 /* ---------------
  * Macro accessors
  * --------------- */
 
-#define SODERLIND_CONTENT(C)    ((SUNAdaptControllerContent_Soderlind)(C->content))
-#define SODERLIND_K1(C)         (SODERLIND_CONTENT(C)->k1)
-#define SODERLIND_K2(C)         (SODERLIND_CONTENT(C)->k2)
-#define SODERLIND_K3(C)         (SODERLIND_CONTENT(C)->k3)
-#define SODERLIND_K4(C)         (SODERLIND_CONTENT(C)->k4)
-#define SODERLIND_K5(C)         (SODERLIND_CONTENT(C)->k5)
-#define SODERLIND_BIAS(C)       (SODERLIND_CONTENT(C)->bias)
-#define SODERLIND_EP(C)         (SODERLIND_CONTENT(C)->ep)
-#define SODERLIND_EPP(C)        (SODERLIND_CONTENT(C)->epp)
-#define SODERLIND_HP(C)         (SODERLIND_CONTENT(C)->hp)
-#define SODERLIND_HPP(C)        (SODERLIND_CONTENT(C)->hpp)
-#define SODERLIND_FIRSTSTEPS(C) (SODERLIND_CONTENT(C)->firststeps)
+#define SODERLIND_CONTENT(C)     ((SUNAdaptControllerContent_Soderlind)(C->content))
+#define SODERLIND_K1(C)          (SODERLIND_CONTENT(C)->k1)
+#define SODERLIND_K2(C)          (SODERLIND_CONTENT(C)->k2)
+#define SODERLIND_K3(C)          (SODERLIND_CONTENT(C)->k3)
+#define SODERLIND_K4(C)          (SODERLIND_CONTENT(C)->k4)
+#define SODERLIND_K5(C)          (SODERLIND_CONTENT(C)->k5)
+#define SODERLIND_BIAS(C)        (SODERLIND_CONTENT(C)->bias)
+#define SODERLIND_EP(C)          (SODERLIND_CONTENT(C)->ep)
+#define SODERLIND_EPP(C)         (SODERLIND_CONTENT(C)->epp)
+#define SODERLIND_HP(C)          (SODERLIND_CONTENT(C)->hp)
+#define SODERLIND_HPP(C)         (SODERLIND_CONTENT(C)->hpp)
+#define SODERLIND_FIRSTSTEPS(C)  (SODERLIND_CONTENT(C)->firststeps)
+#define SODERLIND_HISTORYSIZE(C) (SODERLIND_CONTENT(C)->historysize)
 
 /* ------------------
  * Default parameters
@@ -59,28 +62,24 @@
 #define DEFAULT_EXPGUS_K2 SUN_RCONST(0.268)
 #define DEFAULT_IMPGUS_K1 SUN_RCONST(0.98) /* Implicit Gustafsson parameters */
 #define DEFAULT_IMPGUS_K2 SUN_RCONST(0.95)
-#define DEFAULT_BIAS      SUN_RCONST(1.5)
-#define TINY              SUN_RCONST(1.0e-10)
+#define DEFAULT_BIAS      SUN_RCONST(1.0)
 
 /* -----------------------------------------------------------------
  * exported functions
  * ----------------------------------------------------------------- */
 
 /* -----------------------------------------------------------------
- * Function to create a new Soderlind controller
+ * Function to create a new Soderlind controller (a.k.a., H_{0}321)
  */
 
 SUNAdaptController SUNAdaptController_Soderlind(SUNContext sunctx)
 {
   SUNFunctionBegin(sunctx);
 
-  SUNAdaptController C;
-  SUNAdaptControllerContent_Soderlind content;
-
   /* Create an empty controller object */
-  C = NULL;
-  C = SUNAdaptController_NewEmpty(sunctx);
+  SUNAdaptController C = SUNAdaptController_NewEmpty(sunctx);
   SUNCheckLastErrNull();
+  SUNAdaptControllerContent_Soderlind content = NULL;
 
   /* Attach operations */
   C->ops->gettype      = SUNAdaptController_GetType_Soderlind;
@@ -93,11 +92,8 @@ SUNAdaptController SUNAdaptController_Soderlind(SUNContext sunctx)
   C->ops->space        = SUNAdaptController_Space_Soderlind;
 
   /* Create content */
-  content = NULL;
-  content = (SUNAdaptControllerContent_Soderlind)malloc(sizeof *content);
+  content = (SUNAdaptControllerContent_Soderlind)malloc(sizeof(*content));
   SUNAssertNull(content, SUN_ERR_MALLOC_FAIL);
-
-  /* Attach content */
   C->content = content;
 
   /* Fill content with default/reset values */
@@ -122,6 +118,16 @@ SUNErrCode SUNAdaptController_SetParams_Soderlind(SUNAdaptController C,
   SODERLIND_K3(C) = k3;
   SODERLIND_K4(C) = k4;
   SODERLIND_K5(C) = k5;
+
+  if (k5 != SUN_RCONST(0.0) || k3 != SUN_RCONST(0.0))
+  {
+    SODERLIND_HISTORYSIZE(C) = 2;
+  }
+  else if (k4 != SUN_RCONST(0.0) || k2 != SUN_RCONST(0.0))
+  {
+    SODERLIND_HISTORYSIZE(C) = 1;
+  }
+  else { SODERLIND_HISTORYSIZE(C) = 0; }
   return SUN_SUCCESS;
 }
 
@@ -151,12 +157,8 @@ SUNErrCode SUNAdaptController_SetParams_PID(SUNAdaptController C, sunrealtype k1
                                             sunrealtype k2, sunrealtype k3)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C) = k1;
-  SODERLIND_K2(C) = k2;
-  SODERLIND_K3(C) = k3;
-  SODERLIND_K4(C) = SUN_RCONST(0.0);
-  SODERLIND_K5(C) = SUN_RCONST(0.0);
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_Soderlind(C, k1, k2, k3, SUN_RCONST(0.0),
+                                                SUN_RCONST(0.0));
 }
 
 /* -----------------------------------------------------------------
@@ -167,8 +169,7 @@ SUNAdaptController SUNAdaptController_PI(SUNContext sunctx)
 {
   SUNFunctionBegin(sunctx);
 
-  SUNAdaptController C;
-  C = SUNAdaptController_Soderlind(sunctx);
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
   SUNCheckLastErrNull();
 
   SUNCheckCallNull(
@@ -185,12 +186,8 @@ SUNErrCode SUNAdaptController_SetParams_PI(SUNAdaptController C, sunrealtype k1,
                                            sunrealtype k2)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C) = k1;
-  SODERLIND_K2(C) = k2;
-  SODERLIND_K3(C) = SUN_RCONST(0.0);
-  SODERLIND_K4(C) = SUN_RCONST(0.0);
-  SODERLIND_K5(C) = SUN_RCONST(0.0);
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_Soderlind(C, k1, k2, SUN_RCONST(0.0),
+                                                SUN_RCONST(0.0), SUN_RCONST(0.0));
 }
 
 /* -----------------------------------------------------------------
@@ -201,8 +198,7 @@ SUNAdaptController SUNAdaptController_I(SUNContext sunctx)
 {
   SUNFunctionBegin(sunctx);
 
-  SUNAdaptController C;
-  C = SUNAdaptController_Soderlind(sunctx);
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
   SUNCheckLastErrNull();
 
   SUNCheckCallNull(SUNAdaptController_SetParams_I(C, DEFAULT_I_K1));
@@ -217,12 +213,9 @@ SUNAdaptController SUNAdaptController_I(SUNContext sunctx)
 SUNErrCode SUNAdaptController_SetParams_I(SUNAdaptController C, sunrealtype k1)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C) = k1;
-  SODERLIND_K2(C) = SUN_RCONST(0.0);
-  SODERLIND_K3(C) = SUN_RCONST(0.0);
-  SODERLIND_K4(C) = SUN_RCONST(0.0);
-  SODERLIND_K5(C) = SUN_RCONST(0.0);
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_Soderlind(C, k1, SUN_RCONST(0.0),
+                                                SUN_RCONST(0.0), SUN_RCONST(0.0),
+                                                SUN_RCONST(0.0));
 }
 
 /* -----------------------------------------------------------------
@@ -233,8 +226,7 @@ SUNAdaptController SUNAdaptController_ExpGus(SUNContext sunctx)
 {
   SUNFunctionBegin(sunctx);
 
-  SUNAdaptController C;
-  C = SUNAdaptController_Soderlind(sunctx);
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
   SUNCheckLastErrNull();
 
   SUNCheckCallNull(SUNAdaptController_SetParams_ExpGus(C, DEFAULT_EXPGUS_K1,
@@ -251,12 +243,8 @@ SUNErrCode SUNAdaptController_SetParams_ExpGus(SUNAdaptController C,
                                                sunrealtype k1, sunrealtype k2)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C) = k1 + k2;
-  SODERLIND_K2(C) = -k2;
-  SODERLIND_K3(C) = SUN_RCONST(0.0);
-  SODERLIND_K4(C) = SUN_RCONST(0.0);
-  SODERLIND_K5(C) = SUN_RCONST(0.0);
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_Soderlind(C, k1 + k2, -k2, SUN_RCONST(0.0),
+                                                SUN_RCONST(0.0), SUN_RCONST(0.0));
 }
 
 /* -----------------------------------------------------------------
@@ -267,8 +255,7 @@ SUNAdaptController SUNAdaptController_ImpGus(SUNContext sunctx)
 {
   SUNFunctionBegin(sunctx);
 
-  SUNAdaptController C;
-  C = SUNAdaptController_Soderlind(sunctx);
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
   SUNCheckLastErrNull();
 
   SUNCheckCallNull(SUNAdaptController_SetParams_ImpGus(C, DEFAULT_IMPGUS_K1,
@@ -285,19 +272,95 @@ SUNErrCode SUNAdaptController_SetParams_ImpGus(SUNAdaptController C,
                                                sunrealtype k1, sunrealtype k2)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C) = k1 + k2;
-  SODERLIND_K2(C) = -k2;
-  SODERLIND_K3(C) = SUN_RCONST(0.0);
-  SODERLIND_K4(C) = SUN_RCONST(1.0);
-  SODERLIND_K5(C) = SUN_RCONST(0.0);
+  return SUNAdaptController_SetParams_Soderlind(C, k1 + k2, -k2, SUN_RCONST(0.0),
+                                                SUN_RCONST(1.0), SUN_RCONST(0.0));
   return SUN_SUCCESS;
 }
 
+/* -----------------------------------------------------------------
+ * Function to create an H_{0}211 controller (subset of Soderlind)
+ */
+
+SUNAdaptController SUNAdaptController_H0211(SUNContext sunctx)
+{
+  SUNFunctionBegin(sunctx);
+
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
+  SUNCheckLastErrNull();
+
+  SUNCheckCallNull(
+    SUNAdaptController_SetParams_Soderlind(C, SUN_RCONST(0.5), SUN_RCONST(0.5),
+                                           SUN_RCONST(0.0), -SUN_RCONST(0.5),
+                                           SUN_RCONST(0.0)));
+
+  return (C);
+}
+
+/* -----------------------------------------------------------------
+ * Function to create an H_{0}321 controller (subset of Soderlind)
+ */
+
+SUNAdaptController SUNAdaptController_H0321(SUNContext sunctx)
+{
+  SUNFunctionBegin(sunctx);
+
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
+  SUNCheckLastErrNull();
+
+  SUNCheckCallNull(
+    SUNAdaptController_SetParams_Soderlind(C, SUN_RCONST(1.25), SUN_RCONST(0.5),
+                                           -SUN_RCONST(0.75), SUN_RCONST(0.25),
+                                           SUN_RCONST(0.75)));
+
+  return (C);
+}
+
+/* -----------------------------------------------------------------
+ * Function to create an H211 controller (subset of Soderlind)
+ */
+
+SUNAdaptController SUNAdaptController_H211(SUNContext sunctx)
+{
+  SUNFunctionBegin(sunctx);
+
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
+  SUNCheckLastErrNull();
+
+  SUNCheckCallNull(
+    SUNAdaptController_SetParams_Soderlind(C, SUN_RCONST(0.25),
+                                           SUN_RCONST(0.25), SUN_RCONST(0.0),
+                                           -SUN_RCONST(0.25), SUN_RCONST(0.0)));
+
+  return (C);
+}
+
+/* -----------------------------------------------------------------
+ * Function to create an H312 controller (subset of Soderlind)
+ */
+
+SUNAdaptController SUNAdaptController_H312(SUNContext sunctx)
+{
+  SUNFunctionBegin(sunctx);
+
+  SUNAdaptController C = SUNAdaptController_Soderlind(sunctx);
+  SUNCheckLastErrNull();
+
+  SUNCheckCallNull(
+    SUNAdaptController_SetParams_Soderlind(C, SUN_RCONST(1.0) / SUN_RCONST(8.0),
+                                           SUN_RCONST(0.25),
+                                           SUN_RCONST(1.0) / SUN_RCONST(8.0),
+                                           -SUN_RCONST(3.0) / SUN_RCONST(8.0),
+                                           -SUN_RCONST(1.0) / SUN_RCONST(8.0)));
+
+  return (C);
+}
+
 /* -----------------------------------------------------------------
  * implementation of controller operations
  * ----------------------------------------------------------------- */
 
-SUNAdaptController_Type SUNAdaptController_GetType_Soderlind(SUNAdaptController C)
+SUNAdaptController_Type SUNAdaptController_GetType_Soderlind(
+  SUNDIALS_MAYBE_UNUSED SUNAdaptController C)
 {
   return SUN_ADAPTCONTROLLER_H;
 }
@@ -308,33 +371,39 @@ SUNErrCode SUNAdaptController_EstimateStep_Soderlind(SUNAdaptController C,
                                                      sunrealtype* hnew)
 {
   SUNFunctionBegin(C->sunctx);
-  SUNAssert(hnew, SUN_ERR_ARG_CORRUPT);
 
   /* order parameter to use */
-  const int ord = p + 1;
+  const int ord        = p + 1;
+  const sunrealtype e1 = SODERLIND_BIAS(C) * dsm;
 
-  /* set usable time-step adaptivity parameters */
-  const sunrealtype k1    = -SODERLIND_K1(C) / ord;
-  const sunrealtype k2    = -SODERLIND_K2(C) / ord;
-  const sunrealtype k3    = -SODERLIND_K3(C) / ord;
-  const sunrealtype k4    = SODERLIND_K4(C);
-  const sunrealtype k5    = SODERLIND_K5(C);
-  const sunrealtype e1    = SUNMAX(SODERLIND_BIAS(C) * dsm, TINY);
-  const sunrealtype e2    = SUNMAX(SODERLIND_EP(C), TINY);
-  const sunrealtype e3    = SUNMAX(SODERLIND_EPP(C), TINY);
-  const sunrealtype hrat  = h / SODERLIND_HP(C);
-  const sunrealtype hrat2 = SODERLIND_HP(C) / SODERLIND_HPP(C);
-
-  /* compute estimated optimal time step size */
-  if (SODERLIND_FIRSTSTEPS(C) < 1) { *hnew = h * SUNRpowerR(e1, k1); }
-  else if (SODERLIND_FIRSTSTEPS(C) < 2)
+  /* Handle the case of insufficient history */
+  if (SODERLIND_FIRSTSTEPS(C) < SODERLIND_HISTORYSIZE(C))
   {
-    *hnew = h * SUNRpowerR(e1, k1) * SUNRpowerR(e2, k2) * SUNRpowerR(hrat, k4);
+    /* Fall back onto an I controller */
+    *hnew = h * SUNRpowerR(e1, -SUN_RCONST(1.0) / ord);
+    return SUN_SUCCESS;
   }
-  else
+
+  const sunrealtype k1 = -SODERLIND_K1(C) / ord;
+  *hnew                = h * SUNRpowerR(e1, k1);
+
+  /* This branching is not ideal, but it's more efficient than computing extra
+   * math operations with degenerate k values. */
+  /* TODO(SBR): Consider making separate subclasses for I and PI controllers for
+   * improved efficiency */
+  if (SODERLIND_HISTORYSIZE(C) > 0)
   {
-    *hnew = h * SUNRpowerR(e1, k1) * SUNRpowerR(e2, k2) * SUNRpowerR(e3, k3) *
-            SUNRpowerR(hrat, k4) * SUNRpowerR(hrat2, k5);
+    const sunrealtype k2    = -SODERLIND_K2(C) / ord;
+    const sunrealtype hrat1 = h / SODERLIND_HP(C);
+    *hnew *= SUNRpowerR(SODERLIND_EP(C), k2) * SUNRpowerR(hrat1, SODERLIND_K4(C));
+
+    if (SODERLIND_HISTORYSIZE(C) > 1)
+    {
+      const sunrealtype k3    = -SODERLIND_K3(C) / ord;
+      const sunrealtype hrat2 = SODERLIND_HP(C) / SODERLIND_HPP(C);
+      *hnew *= SUNRpowerR(SODERLIND_EPP(C), k3) *
+               SUNRpowerR(hrat2, SODERLIND_K5(C));
+    }
   }
 
   /* return with success */
@@ -355,13 +424,10 @@ SUNErrCode SUNAdaptController_Reset_Soderlind(SUNAdaptController C)
 SUNErrCode SUNAdaptController_SetDefaults_Soderlind(SUNAdaptController C)
 {
   SUNFunctionBegin(C->sunctx);
-  SODERLIND_K1(C)   = DEFAULT_K1;
-  SODERLIND_K2(C)   = DEFAULT_K2;
-  SODERLIND_K3(C)   = DEFAULT_K3;
-  SODERLIND_K4(C)   = DEFAULT_K4;
-  SODERLIND_K5(C)   = DEFAULT_K5;
   SODERLIND_BIAS(C) = DEFAULT_BIAS;
-  return SUN_SUCCESS;
+  return SUNAdaptController_SetParams_Soderlind(C, DEFAULT_K1, DEFAULT_K2,
+                                                DEFAULT_K3, DEFAULT_K4,
+                                                DEFAULT_K5);
 }
 
 SUNErrCode SUNAdaptController_Write_Soderlind(SUNAdaptController C, FILE* fptr)
@@ -369,30 +435,20 @@ SUNErrCode SUNAdaptController_Write_Soderlind(SUNAdaptController C, FILE* fptr)
   SUNFunctionBegin(C->sunctx);
   SUNAssert(fptr, SUN_ERR_ARG_CORRUPT);
   fprintf(fptr, "Soderlind SUNAdaptController module:\n");
-#if defined(SUNDIALS_EXTENDED_PRECISION)
-  fprintf(fptr, "  k1 = %32Lg\n", SODERLIND_K1(C));
-  fprintf(fptr, "  k2 = %32Lg\n", SODERLIND_K2(C));
-  fprintf(fptr, "  k3 = %32Lg\n", SODERLIND_K3(C));
-  fprintf(fptr, "  k4 = %32Lg\n", SODERLIND_K4(C));
-  fprintf(fptr, "  k5 = %32Lg\n", SODERLIND_K5(C));
-  fprintf(fptr, "  bias factor = %22Lg\n", SODERLIND_BIAS(C));
-  fprintf(fptr, "  previous error = %22Lg\n", SODERLIND_EP(C));
-  fprintf(fptr, "  previous-previous error = %22Lg\n", SODERLIND_EPP(C));
-  fprintf(fptr, "  previous step = %22Lg\n", SODERLIND_HP(C));
-  fprintf(fptr, "  previous-previous step = %22Lg\n", SODERLIND_HPP(C));
-#else
-  fprintf(fptr, "  k1 = %16g\n", SODERLIND_K1(C));
-  fprintf(fptr, "  k2 = %16g\n", SODERLIND_K2(C));
-  fprintf(fptr, "  k3 = %16g\n", SODERLIND_K3(C));
-  fprintf(fptr, "  k4 = %16g\n", SODERLIND_K4(C));
-  fprintf(fptr, "  k5 = %16g\n", SODERLIND_K5(C));
-  fprintf(fptr, "  bias factor = %16g\n", SODERLIND_BIAS(C));
-  fprintf(fptr, "  previous error = %16g\n", SODERLIND_EP(C));
-  fprintf(fptr, "  previous-previous error = %16g\n", SODERLIND_EPP(C));
-  fprintf(fptr, "  previous step = %16g\n", SODERLIND_HP(C));
-  fprintf(fptr, "  previous-previous step = %16g\n", SODERLIND_HPP(C));
-#endif
+  fprintf(fptr, "  k1 = " SUN_FORMAT_G "\n", SODERLIND_K1(C));
+  fprintf(fptr, "  k2 = " SUN_FORMAT_G "\n", SODERLIND_K2(C));
+  fprintf(fptr, "  k3 = " SUN_FORMAT_G "\n", SODERLIND_K3(C));
+  fprintf(fptr, "  k4 = " SUN_FORMAT_G "\n", SODERLIND_K4(C));
+  fprintf(fptr, "  k5 = " SUN_FORMAT_G "\n", SODERLIND_K5(C));
+  fprintf(fptr, "  bias factor = " SUN_FORMAT_G "\n", SODERLIND_BIAS(C));
+  fprintf(fptr, "  previous error = " SUN_FORMAT_G "\n", SODERLIND_EP(C));
+  fprintf(fptr, "  previous-previous error = " SUN_FORMAT_G "\n",
+          SODERLIND_EPP(C));
+  fprintf(fptr, "  previous step = " SUN_FORMAT_G "\n", SODERLIND_HP(C));
+  fprintf(fptr, "  previous-previous step = " SUN_FORMAT_G "\n",
+          SODERLIND_HPP(C));
   fprintf(fptr, "  firststeps = %i\n", SODERLIND_FIRSTSTEPS(C));
+  fprintf(fptr, "  historysize = %i\n", SODERLIND_HISTORYSIZE(C));
   return SUN_SUCCESS;
 }
 
@@ -416,7 +472,10 @@ SUNErrCode SUNAdaptController_UpdateH_Soderlind(SUNAdaptController C,
   SODERLIND_EP(C)  = SODERLIND_BIAS(C) * dsm;
   SODERLIND_HPP(C) = SODERLIND_HP(C);
   SODERLIND_HP(C)  = h;
-  if (SODERLIND_FIRSTSTEPS(C) < 2) { SODERLIND_FIRSTSTEPS(C) += 1; }
+  if (SODERLIND_FIRSTSTEPS(C) < SODERLIND_HISTORYSIZE(C))
+  {
+    SODERLIND_FIRSTSTEPS(C) += 1;
+  }
   return SUN_SUCCESS;
 }
 
@@ -427,6 +486,6 @@ SUNErrCode SUNAdaptController_Space_Soderlind(SUNAdaptController C,
   SUNAssert(lenrw, SUN_ERR_ARG_CORRUPT);
   SUNAssert(leniw, SUN_ERR_ARG_CORRUPT);
   *lenrw = 10;
-  *leniw = 1;
+  *leniw = 2;
   return SUN_SUCCESS;
 }
